summaryrefslogtreecommitdiff
path: root/passwd/apr_getpass.c
diff options
context:
space:
mode:
authordougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2000-08-02 05:26:45 +0000
committerdougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2000-08-02 05:26:45 +0000
commit8fcf6e0fadd7ec31d02e7249dc69922b24747c11 (patch)
tree4da0bfd73d36292921960aaabc877a57e680b8c4 /passwd/apr_getpass.c
parent5198c260c1982414023e984799ce1c3b04bb6b43 (diff)
downloadlibapr-8fcf6e0fadd7ec31d02e7249dc69922b24747c11.tar.gz
prefix libapr functions and types with apr_
git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@60470 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'passwd/apr_getpass.c')
-rw-r--r--passwd/apr_getpass.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/passwd/apr_getpass.c b/passwd/apr_getpass.c
index 2c1797775..e714aa779 100644
--- a/passwd/apr_getpass.c
+++ b/passwd/apr_getpass.c
@@ -52,7 +52,7 @@
* <http://www.apache.org/>.
*/
/* ap_getpass.c: abstraction to provide for obtaining a password from the
* command line in whatever way the OS supports. In the best case, it's a
* wrapper for the system library's getpass() routine; otherwise, we
* use one we define ourselves.
@@ -204,7 +204,7 @@ static char *getpass(const char *prompt)
* but the caller is *not* made aware of it.
*/
-APR_EXPORT(ap_status_t) ap_getpass(const char *prompt, char *pwbuf, size_t *bufsiz)
+APR_EXPORT(apr_status_t) apr_getpass(const char *prompt, char *pwbuf, size_t *bufsiz)
{
char *pw_got = NULL;
int result = 0;
@@ -214,7 +214,7 @@ APR_EXPORT(ap_status_t) ap_getpass(const char *prompt, char *pwbuf, size_t *bufs
*bufsiz = ERR_OVERFLOW;
return APR_ENAMETOOLONG;
}
- ap_cpystrn(pwbuf, pw_got, *bufsiz);
+ apr_cpystrn(pwbuf, pw_got, *bufsiz);
*bufsiz = result;
return APR_SUCCESS;
}
@@ -52,7 +52,7 @@
* <http://www.apache.org/>.
*/
-/* ap_getpass.c: abstraction to provide for obtaining a password from the
+/* apr_getpass.c: abstraction to provide for obtaining a password from the
* command line in whatever way the OS supports. In the best case, it's a
* wrapper for the system library's getpass() routine; otherwise, we